==> kubernetes-model-resource-6.5.1-sources.jar: io/fabric8/kubernetes/api/model/resource/v1alpha1/ResourceClaimTemplateListFluent.java <==
package io.fabric8.kubernetes.api.model.resource.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ResourceClaimTemplateListFluent<A extends ResourceClaimTemplateListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,ResourceClaimTemplate item);
  public A setToItems(Integer index,ResourceClaimTemplate item);
  public A addToItems(io.fabric8.kubernetes.api.model.resource.v1alpha1.ResourceClaimTemplate... items);
  public A addAllToItems(Collection<ResourceClaimTemplate> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.resource.v1alpha1.ResourceClaimTemplate... items);
  public A removeAllFromItems(Collection<ResourceClaimTemplate> items);
  public A removeMatchingFromItems(Predicate<ResourceClaimTemplateBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ResourceClaimTemplate> getItems();
  public List<ResourceClaimTemplate> buildItems();
  public ResourceClaimTemplate buildItem(Integer index);
  public ResourceClaimTemplate buildFirstItem();
  public ResourceClaimTemplate buildLastItem();
  public ResourceClaimTemplate buildMatchingItem(Predicate<ResourceClaimTemplateBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ResourceClaimTemplateBuilder> predicate);
  public A withItems(List<ResourceClaimTemplate> items);
  public A withItems(io.fabric8.kubernetes.api.model.resource.v1alpha1.ResourceClaimTemplate... items);
  public Boolean hasItems();
  public ResourceClaimTemplateListFluent.ItemsNested<A> addNewItem();
  public ResourceClaimTemplateListFluent.ItemsNested<A> addNewItemLike(ResourceClaimTemplate item);
  public ResourceClaimTemplateListFluent.ItemsNested<A> setNewItemLike(Integer index,ResourceClaimTemplate item);
  public ResourceClaimTemplateListFluent.ItemsNested<A> editItem(Integer index);
  public ResourceClaimTemplateListFluent.ItemsNested<A> editFirstItem();
  public ResourceClaimTemplateListFluent.ItemsNested<A> editLastItem();
  public ResourceClaimTemplateListFluent.ItemsNested<A> editMatchingItem(Predicate<ResourceClaimTemplateBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,ResourceClaimTemplateFluent<ResourceClaimTemplateListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> kubernetes-model-resource-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/resource/v1alpha1/ResourceClaimTemplateListFluent.java <==
package io.fabric8.kubernetes.api.model.resource.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ResourceClaimTemplateListFluent<A extends ResourceClaimTemplateListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,ResourceClaimTemplate item);
  public A setToItems(int index,ResourceClaimTemplate item);
  public A addToItems(io.fabric8.kubernetes.api.model.resource.v1alpha1.ResourceClaimTemplate... items);
  public A addAllToItems(Collection<ResourceClaimTemplate> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.resource.v1alpha1.ResourceClaimTemplate... items);
  public A removeAllFromItems(Collection<ResourceClaimTemplate> items);
  public A removeMatchingFromItems(Predicate<ResourceClaimTemplateBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ResourceClaimTemplate> getItems();
  public List<ResourceClaimTemplate> buildItems();
  public ResourceClaimTemplate buildItem(int index);
  public ResourceClaimTemplate buildFirstItem();
  public ResourceClaimTemplate buildLastItem();
  public ResourceClaimTemplate buildMatchingItem(Predicate<ResourceClaimTemplateBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ResourceClaimTemplateBuilder> predicate);
  public A withItems(List<ResourceClaimTemplate> items);
  public A withItems(io.fabric8.kubernetes.api.model.resource.v1alpha1.ResourceClaimTemplate... items);
  public Boolean hasItems();
  public ResourceClaimTemplateListFluent.ItemsNested<A> addNewItem();
  public ResourceClaimTemplateListFluent.ItemsNested<A> addNewItemLike(ResourceClaimTemplate item);
  public ResourceClaimTemplateListFluent.ItemsNested<A> setNewItemLike(int index,ResourceClaimTemplate item);
  public ResourceClaimTemplateListFluent.ItemsNested<A> editItem(int index);
  public ResourceClaimTemplateListFluent.ItemsNested<A> editFirstItem();
  public ResourceClaimTemplateListFluent.ItemsNested<A> editLastItem();
  public ResourceClaimTemplateListFluent.ItemsNested<A> editMatchingItem(Predicate<ResourceClaimTemplateBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,ResourceClaimTemplateFluent<ResourceClaimTemplateListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
